@@ -23,12 +23,11 @@
     "redundant_projection",
     "RemoveRedundantBackticks",
     "ObjectPropertyName",
-    "deprecation"
+    "deprecation",
+    "detekt:all"
 )
 @file:org.gradle.api.Generated
 
-/* ktlint-disable */
-
 package org.gradle.kotlin.dsl
 
 
@@ -37,6 +36,6 @@ package org.gradle.kotlin.dsl
  *
  * @see org.gradle.api.plugins.quality.Checkstyle.setConfigProperties
  */
-inline fun org.gradle.api.plugins.quality.Checkstyle.`setConfigProperties`(vararg `p0`: Pair<String, Any?>): Unit =
-    `setConfigProperties`(mapOf(*`p0`))
+inline fun org.gradle.api.plugins.quality.Checkstyle.`setConfigProperties`(vararg `configProperties`: Pair<String, Any>): Unit =
+    `setConfigProperties`(mapOf(*`configProperties`))
 
